==> haskell-natural-transformation-0.4-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-natural-transformation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: natural-transformation
version: 0.4
id: natural-transformation-0.4-1wekIVD0YQa62debXjfFg3
key: natural-transformation-0.4-1wekIVD0YQa62debXjfFg3
license: BSD3
copyright: Copyright (c) 2015-2016 The University of Kansas
maintainer: Andy Gill <andygill@ku.edu>
stability: Provisional
homepage: https://github.com/ku-fpg/natural-transformation
synopsis: A natural transformation package.
description:
    A natural transformation transforms a container @f a@ into another
    container @g a@. Natural transformations act as functor morphisms
    in category theory.
    .
    The naming of '\''~>'\'', '\'':~>'\'' and '\''$$'\'' were taken,
    with permission, from Edward Kmett'\''s @indexed@ package.
category: Control
author: Andy Gill
exposed: True
exposed-modules:
    Control.Natural Control.Natural.RULES Control.Object
abi: e19f41458e4368337ffd0b9efedecad0
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/natural-transformation-0.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/natural-transformation-0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/natural-transformation-0.4
hs-libraries: HSnatural-transformation-0.4-1wekIVD0YQa62debXjfFg3
depends:
    base-4.9.1.0
haddock-interfaces: /usr/share/doc/haskell-natural-transformation/html/natural-transformation.haddock
haddock-html: /usr/share/doc/haskell-natural-transformation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-natural-transformation-0.4-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-natural-transformation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: natural-transformation
version: 0.4
id: natural-transformation-0.4-9NCJslsrUYd345JjsiUU2a
key: natural-transformation-0.4-9NCJslsrUYd345JjsiUU2a
license: BSD3
copyright: Copyright (c) 2015-2016 The University of Kansas
maintainer: Andy Gill <andygill@ku.edu>
stability: Provisional
homepage: https://github.com/ku-fpg/natural-transformation
synopsis: A natural transformation package.
description:
    A natural transformation transforms a container @f a@ into another
    container @g a@. Natural transformations act as functor morphisms
    in category theory.
    .
    The naming of '\''~>'\'', '\'':~>'\'' and '\''$$'\'' were taken,
    with permission, from Edward Kmett'\''s @indexed@ package.
category: Control
author: Andy Gill
exposed: True
indefinite: False
exposed-modules:
    Control.Natural Control.Natural.RULES Control.Object
abi: dac717cedc2638a6ba431e657730b95b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/natural-transformation-0.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/natural-transformation-0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/natural-transformation-0.4
hs-libraries: HSnatural-transformation-0.4-9NCJslsrUYd345JjsiUU2a
depends:
    base-4.10.0.0
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
haddock-interfaces: /usr/share/doc/haskell-natural-transformation/html/natural-transformation.haddock
haddock-html: /usr/share/doc/haskell-natural-transformation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
